package com.hw.mes.mapper;

import java.util.List;
import com.hw.mes.api.domain.MesBaseMaterialInfo;

/**
 * 物料信息Mapper接口
 *
 * @author xins
 * @date 2023-12-21
 */
public interface MesBaseMaterialInfoMapper
{
    /**
     * 查询物料信息
     *
     * @param materialId 物料信息主键
     * @return 物料信息
     */
    public MesBaseMaterialInfo selectMesBaseMaterialInfoByMaterialId(Long materialId);

    /**
     * 查询物料信息列表
     *
     * @param mesBaseMaterialInfo 物料信息
     * @return 物料信息集合
     */
    public List<MesBaseMaterialInfo> selectMesBaseMaterialInfoList(MesBaseMaterialInfo mesBaseMaterialInfo);

    /**
     * 新增物料信息
     *
     * @param mesBaseMaterialInfo 物料信息
     * @return 结果
     */
    public int insertMesBaseMaterialInfo(MesBaseMaterialInfo mesBaseMaterialInfo);

    /**
     * 修改物料信息
     *
     * @param mesBaseMaterialInfo 物料信息
     * @return 结果
     */
    public int updateMesBaseMaterialInfo(MesBaseMaterialInfo mesBaseMaterialInfo);

    /**
     * 删除物料信息
     *
     * @param materialId 物料信息主键
     * @return 结果
     */
    public int deleteMesBaseMaterialInfoByMaterialId(Long materialId);

    /**
     * 批量删除物料信息
     *
     * @param materialIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMesBaseMaterialInfoByMaterialIds(Long[] materialIds);




    /**
     * 查询物料信息列表
     *
     * @param materialIds 物料信息ID列表
     * @return 物料信息集合
     */
    public List<MesBaseMaterialInfo> selectMesBaseMaterialInfoListByMaterialIds(Long[] materialIds);

}
